@@ -262,6 +262,17 @@ class Image(Resource):
             return self[:, idx]
         raise TypeError('unsupported index type: ' + repr(idx))
 
+    def __eq__(self, other):
+        if isinstance(other, type(self)):
+            return self.signature == other.signature
+        return False
+
+    def __ne__(self, other):
+        return not (self == other)
+
+    def __hash__(self):
+        return hash(self.signature)
+
     @property
     def width(self):
         """(:class:`numbers.Integral`) The width of this image."""
@@ -323,6 +334,40 @@ class Image(Resource):
         libc.free(rp)
         return mimetype
 
+    @property
+    def signature(self):
+        """(:class:`str`) The SHA-256 message digest for the image pixel
+        stream.
+
+        """
+        return library.MagickGetImageSignature(self.wand)
+
+    @property
+    def background_color(self):
+        """(:class:`wand.color.Color`) The image background color.
+        It can also be set to change the background color.
+
+        """
+        pixel = library.NewPixelWand()
+        result = library.MagickGetImageBackgroundColor(self.wand, pixel)
+        if result:
+            size = ctypes.sizeof(MagickPixelPacket)
+            buffer = ctypes.create_string_buffer(size)
+            library.PixelGetMagickColor(pixel, buffer)
+            return Color(raw=buffer)
+        self.raise_exception()
+
+    @background_color.setter
+    def background_color(self, color):
+        if not isinstance(color, Color):
+            raise TypeError('color must be a wand.color.Color object, not ' +
+                            repr(color))
+        with color:
+            result = library.MagickSetImageBackgroundColor(self.wand,
+                                                           color.resource)
+            if not result:
+                self.raise_exception()
+
     def convert(self, format):
         """Converts the image format with the original image maintained.
         It returns a converted image instance which is new. ::
